@@ -7,6 +7,7 @@ from tkinter import *
 from tkinter import ttk, filedialog, messagebox
 from bdata import bdata, bmerged
 from scipy.optimize import curve_fit
+from multiprocessing import Process
 
 # set MPL backend
 import matplotlib as mpl
@@ -26,6 +27,8 @@ import matplotlib.pyplot as plt
 import bdata as bd
 import weakref as wref
 
+from multiprocessing import Process, Queue
+import queue
 
 from bfit import __version__, logger_name, icon_path
 from bfit.gui.tab_fileviewer import fileviewer
@@ -39,6 +42,7 @@ from bfit.gui.popup_redraw_period import popup_redraw_period
 from bfit.gui.popup_terminal import popup_terminal
 from bfit.gui.popup_units import popup_units
 from bfit.gui.popup_set_ppm_reference import popup_set_ppm_reference
+from bfit.gui.popup_ongoing_process import popup_ongoing_process
 from bfit.gui.popup_set_histograms import popup_set_histograms
 from bfit.backend.PltTracker import PltTracker
 from bfit.backend.raise_window import raise_window
@@ -104,6 +108,7 @@ class bfit(object):
             logger:         logging object 
             logger_name:    string of unique logger name
             mainframe:      main frame for the object
+            menus:          dict {title: Menu} of menubar options
             minimizer:      StringVar: path to python module with fitter object
             notebook:       contains all tabs for operations:
                 fileviewer
@@ -416,9 +421,6 @@ class bfit(object):
         # File
         menu_file = Menu(menubar, title='File')
         menu_file.add_command(label='Search archive', command=self.search_archive)
-        menu_file.add_command(label='NQR B0 Calculator', command=calculator_nqr_B0)
-        menu_file.add_command(label='NMR B1 Calculator', command=calculator_nmr_B1)
-        menu_file.add_command(label='NMR RF Attenuation', command=calculator_nmr_atten)
         menu_file.add_command(label='Run Commands', command=lambda:popup_terminal(wref.proxy(self)))
         menu_file.add_command(label='Export Data', command=self.do_export)
         menu_file.add_command(label='Export Fits', command=self.do_export_fit)
@@ -487,6 +489,13 @@ class bfit(object):
                     value=k, 
                     command=self.set_thermo_channel)
         
+        # calculate
+        menu_calculate = Menu(menubar, title='Calculate')
+        menubar.add_cascade(menu=menu_calculate, label='Calculate')
+        menu_calculate.add_command(label='NQR B0', command=calculator_nqr_B0)
+        menu_calculate.add_command(label='NMR B1', command=calculator_nmr_B1)
+        menu_calculate.add_command(label='NMR B1 Attenuation', command=calculator_nmr_atten)
+        
         # Draw style
         self.draw_style = StringVar()
         self.draw_style.set("stack")
@@ -583,12 +592,7 @@ class bfit(object):
         self.menus = {'menubar': menubar}
         for child in menubar.winfo_children():
             self.menus[child['title']] = child
-            # ~ print(child.keys())
-            # ~ for child2 in child.winfo_children():
-                # ~ print(child2['name'])
-        
-        # ~ print(self.menus)
-        
+            
         # testing
         if testfn is not None: 
             testfn(self)
@@ -1713,10 +1717,35 @@ class bfit(object):
     # ======================================================================= #
     def update_bfit(self):
         """Check pip for updated version"""
+        
         self.logger.info('Using pip to update')
-        subprocess.call([sys.executable, "-m", "pip", "install", "--user", 
-                         "--upgrade", 'bfit'])
-        print('Done. Restart to implement updates.')
+        
+        # set up queue to get signal
+        que = Queue()
+        
+        # run update function
+        def do_update():
+            try:
+                subprocess.call([sys.executable, "-m", "pip", "install", 
+                                 "--user", "--upgrade", 'bfit'])
+            except subprocess.CalledProcessError:
+                que.put('Error')
+            else:
+                que.put('Success')
+        
+        popup = popup_ongoing_process(self, 
+                            target = do_update,
+                            message="Updating bfit...", 
+                            queue = que)
+        output = popup.run()
+        
+        # end update
+        if output == 'Error':
+            messagebox.showerror("Error", 'Update error. Use command line to update.')
+        elif output == 'Success':
+            messagebox.showinfo("Success", 'Close window and restart bfit to implement updates.')
+        else:
+            return
      
     # ======================================================================= #
     def whatsnew(self):
