@@ -87,7 +87,7 @@ class fetch_files(object):
         
         entry_year = Spinbox(fet_entry_frame, textvariable=self.year, width=5, 
                              from_=2000, to=datetime.datetime.today().year)
-        entry_run = ttk.Entry(fet_entry_frame, textvariable=self.run, width=100)
+        entry_run = Entry(fet_entry_frame, textvariable=self.run, width=100)
         entry_run.insert(0, self.run_number_starter_line)
         entry_run.config(foreground=colors.entry_grey)
         
@@ -158,9 +158,14 @@ class fetch_files(object):
         check_rebin_box = Spinbox(right_frame, from_=1, to=100, width=3, \
                 textvariable=self.check_rebin, 
                 command=self.set_all)
-        check_bin_remove_entry = ttk.Entry(right_frame, \
+        check_bin_remove_entry = Entry(right_frame, \
                 textvariable=self.check_bin_remove, width=20)
         
+        # key bindings
+        check_bin_remove_entry.bind('<KeyRelease>', self.set_all)
+        check_rebin_box.bind('<KeyRelease>', self.set_all)
+        
+        
         check_all_box = ttk.Checkbutton(right_frame, 
                 text='Force Check State', variable=self.check_state, 
                 onvalue=True, offvalue=False, pad=5, command=self.check_all)
@@ -201,7 +206,7 @@ class fetch_files(object):
         check_bin_remove_entry.bind('<FocusIn>', check_entry_fn)
         check_bin_remove_entry.bind('<FocusOut>', check_on_focusout_fn)
         check_bin_remove_entry.config(foreground=colors.entry_grey)
-                
+                    
         # grid
         runmode_label_frame.grid(column=2, row=0, sticky=(N, W, E, S), pady=5, padx=5)
         self.runmode_label.grid(column=0, row=0, sticky=(N, W, E))
@@ -679,11 +684,7 @@ class fetch_files(object):
             self.get_data()
             self.history_hide()
         
-        # checked rebin or checked run omission
-        elif focus_id in [self.check_rebin_box, \
-                          self.check_bin_remove_entry]:
-            self.logger.debug('Focus is: checked rebin or checked run omission')
-            self.set_all()
+        # check all box
         elif focus_id == self.check_all_box:
             self.logger.debug('Focus is: check all box')
             self.draw_all()
@@ -691,7 +692,7 @@ class fetch_files(object):
             pass
 
     # ======================================================================= #
-    def set_all(self):
+    def set_all(self, *args):
         """Set a particular property for all checked items. """
         
         self.logger.info('Set all')
@@ -703,7 +704,12 @@ class fetch_files(object):
             if self.data_lines[r].check_state.get():
                 
                 # get values to enter
-                self.data_lines[r].rebin.set(self.check_rebin.get())
+                try:
+                    rebin = self.check_rebin.get()
+                except TclError:
+                    rebin = 1
+                    
+                self.data_lines[r].rebin.set(rebin)
                 new_text = self.check_bin_remove.get()
                 
                 # check for greyed text
@@ -880,11 +886,11 @@ class dataline(object):
         line_frame.bind('<Enter>', self.on_line_enter)
         line_frame.bind('<Leave>', self.on_line_leave)
         
-        bin_remove_entry = ttk.Entry(line_frame, textvariable=self.bin_remove, \
+        bin_remove_entry = Entry(line_frame, textvariable=self.bin_remove, \
                 width=17)
                 
         label_label = ttk.Label(line_frame, text="Label:", pad=5)
-        self.label_entry = ttk.Entry(line_frame, textvariable=self.label, \
+        self.label_entry = Entry(line_frame, textvariable=self.label, \
                 width=18)
                 
         remove_button = ttk.Button(line_frame, text='Remove', \
